From 7d89e122930be39e84a6d174548fa2d12ac0484a Mon Sep 17 00:00:00 2001
From: Teravus Ovares
Date: Sat, 6 Sep 2008 07:52:41 +0000
Subject: * This is the fabled LibOMV update with all of the libOMV types from
JHurliman * This is a HUGE OMG update and will definitely have unknown side
effects.. so this is really only for the strong hearted at this point.
Regular people should let the dust settle. * This has been tested to work
with most basic functions. However.. make sure you back up 'everything'
before using this. It's that big! * Essentially we're back at square 1 in
the testing phase.. so lets identify things that broke.
---
.../Framework/Communications/Cache/AssetCache.cs | 52 +++++++--------
.../Communications/Cache/AssetServerBase.cs | 4 +-
.../Communications/Cache/CachedUserInfo.cs | 54 +++++++--------
.../Communications/Cache/FileAssetClient.cs | 16 +++--
.../Communications/Cache/InventoryFolderImpl.cs | 14 ++--
.../Communications/Cache/LibraryRootFolder.cs | 46 ++++++-------
.../Cache/UserProfileCacheService.cs | 38 +++++------
.../Framework/Communications/Capabilities/Caps.cs | 76 +++++++++++-----------
.../Framework/Communications/Capabilities/LLSD.cs | 24 +++----
.../Capabilities/LLSDAssetUploadComplete.cs | 6 +-
.../Capabilities/LLSDAssetUploadRequest.cs | 6 +-
.../Communications/Capabilities/LLSDHelpers.cs | 14 ++--
.../Capabilities/LLSDInventoryItem.cs | 26 ++++----
.../Communications/Capabilities/LLSDItemUpdate.cs | 6 +-
.../Communications/Capabilities/LLSDMapLayer.cs | 6 +-
.../Capabilities/LLSDRemoteParcelResponse.cs | 4 +-
.../Capabilities/LLSDStreamHandler.cs | 6 +-
.../LLSDTaskInventoryUploadComplete.cs | 8 +--
.../Capabilities/LLSDTaskScriptUpdate.cs | 8 +--
.../Communications/CommunicationsManager.cs | 34 +++++-----
OpenSim/Framework/Communications/IAvatarService.cs | 6 +-
OpenSim/Framework/Communications/IGridServices.cs | 4 +-
.../Communications/IInterRegionCommunications.cs | 14 ++--
.../IInterServiceInventoryServices.cs | 6 +-
.../Framework/Communications/IInventoryServices.cs | 8 +--
.../Communications/ISecureInventoryService.cs | 22 +++----
OpenSim/Framework/Communications/IUserService.cs | 40 ++++++------
.../Communications/InventoryServiceBase.cs | 58 ++++++++---------
OpenSim/Framework/Communications/LoginResponse.cs | 32 ++++-----
OpenSim/Framework/Communications/LoginService.cs | 28 ++++----
.../Framework/Communications/UserManagerBase.cs | 68 +++++++++----------
31 files changed, 369 insertions(+), 365 deletions(-)
(limited to 'OpenSim/Framework/Communications')
diff --git a/OpenSim/Framework/Communications/Cache/AssetCache.cs b/OpenSim/Framework/Communications/Cache/AssetCache.cs
index e924b3f..3e88eba 100644
--- a/OpenSim/Framework/Communications/Cache/AssetCache.cs
+++ b/OpenSim/Framework/Communications/Cache/AssetCache.cs
@@ -29,14 +29,14 @@ using System;
using System.Collections.Generic;
using System.Reflection;
using System.Threading;
-using libsecondlife;
-using libsecondlife.Packets;
+using OpenMetaverse;
+using OpenMetaverse.Packets;
using log4net;
using OpenSim.Framework.Statistics;
namespace OpenSim.Framework.Communications.Cache
{
- public delegate void AssetRequestCallback(LLUUID assetID, AssetBase asset);
+ public delegate void AssetRequestCallback(UUID assetID, AssetBase asset);
///
/// Manages local cache of assets and their sending to viewers.
@@ -58,17 +58,17 @@ namespace OpenSim.Framework.Communications.Cache
///
/// The cache of assets. This does not include textures.
///
- private Dictionary Assets;
+ private Dictionary Assets;
///
/// The cache of textures.
///
- private Dictionary Textures;
+ private Dictionary Textures;
///
/// Assets requests which are waiting for asset server data. This includes texture requests
///
- private Dictionary RequestedAssets;
+ private Dictionary RequestedAssets;
///
/// Asset requests with data which are ready to be sent back to requesters. This includes textures.
@@ -78,7 +78,7 @@ namespace OpenSim.Framework.Communications.Cache
///
/// Until the asset request is fulfilled, each asset request is associated with a list of requesters
///
- private Dictionary RequestLists;
+ private Dictionary RequestLists;
private readonly IAssetServer m_assetServer;
@@ -155,12 +155,12 @@ namespace OpenSim.Framework.Communications.Cache
///
private void Initialize()
{
- Assets = new Dictionary();
- Textures = new Dictionary();
+ Assets = new Dictionary();
+ Textures = new Dictionary();
AssetRequests = new List();
- RequestedAssets = new Dictionary();
- RequestLists = new Dictionary();
+ RequestedAssets = new Dictionary();
+ RequestLists = new Dictionary();
}
///
@@ -207,7 +207,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- //private AssetBase GetCachedAsset(LLUUID assetId)
+ //private AssetBase GetCachedAsset(UUID assetId)
//{
// AssetBase asset = null;
@@ -223,7 +223,7 @@ namespace OpenSim.Framework.Communications.Cache
// return asset;
//}
- private bool TryGetCachedAsset(LLUUID assetId, out AssetBase asset)
+ private bool TryGetCachedAsset(UUID assetId, out AssetBase asset)
{
if (Textures.ContainsKey(assetId))
{
@@ -248,7 +248,7 @@ namespace OpenSim.Framework.Communications.Cache
/// A callback invoked when the asset has either been found or not found.
/// If the asset was found this is called with the asset UUID and the asset data
/// If the asset was not found this is still called with the asset UUID but with a null asset data reference
- public void GetAsset(LLUUID assetId, AssetRequestCallback callback, bool isTexture)
+ public void GetAsset(UUID assetId, AssetRequestCallback callback, bool isTexture)
{
//m_log.DebugFormat("[ASSET CACHE]: Requesting {0} {1}", isTexture ? "texture" : "asset", assetId);
@@ -308,7 +308,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// null if the asset could not be retrieved
- public AssetBase GetAsset(LLUUID assetID, bool isTexture)
+ public AssetBase GetAsset(UUID assetID, bool isTexture)
{
// I'm not going over 3 seconds since this will be blocking processing of all the other inbound
// packets from the client.
@@ -390,7 +390,7 @@ namespace OpenSim.Framework.Communications.Cache
/// this is a stop gap measure until we have such a thing.
///
- public void ExpireAsset(LLUUID uuid)
+ public void ExpireAsset(UUID uuid)
{
// uuid is unique, so no need to worry about it showing up
// in the 2 caches differently. Also, locks are probably
@@ -495,7 +495,7 @@ namespace OpenSim.Framework.Communications.Cache
}
// See IAssetReceiver
- public void AssetNotFound(LLUUID assetID, bool IsTexture)
+ public void AssetNotFound(UUID assetID, bool IsTexture)
{
//m_log.WarnFormat("[ASSET CACHE]: AssetNotFound for {0}", assetID);
@@ -567,17 +567,17 @@ namespace OpenSim.Framework.Communications.Cache
///
public void AddAssetRequest(IClientAPI userInfo, TransferRequestPacket transferRequest)
{
- LLUUID requestID = null;
+ UUID requestID = null;
byte source = 2;
if (transferRequest.TransferInfo.SourceType == 2)
{
//direct asset request
- requestID = new LLUUID(transferRequest.TransferInfo.Params, 0);
+ requestID = new UUID(transferRequest.TransferInfo.Params, 0);
}
else if (transferRequest.TransferInfo.SourceType == 3)
{
//inventory asset request
- requestID = new LLUUID(transferRequest.TransferInfo.Params, 80);
+ requestID = new UUID(transferRequest.TransferInfo.Params, 80);
source = 3;
//Console.WriteLine("asset request " + requestID);
}
@@ -678,10 +678,10 @@ namespace OpenSim.Framework.Communications.Cache
public class AssetRequest
{
public IClientAPI RequestUser;
- public LLUUID RequestAssetID;
+ public UUID RequestAssetID;
public AssetInfo AssetInf;
public TextureImage ImageInfo;
- public LLUUID TransferRequestID;
+ public UUID TransferRequestID;
public long DataPointer = 0;
public int NumPackets = 0;
public int PacketCounter = 0;
@@ -731,10 +731,10 @@ namespace OpenSim.Framework.Communications.Cache
public class AssetRequestsList
{
- public LLUUID AssetID;
+ public UUID AssetID;
public List Requests = new List();
- public AssetRequestsList(LLUUID assetID)
+ public AssetRequestsList(UUID assetID)
{
AssetID = assetID;
}
@@ -742,10 +742,10 @@ namespace OpenSim.Framework.Communications.Cache
public class NewAssetRequest
{
- public LLUUID AssetID;
+ public UUID AssetID;
public AssetRequestCallback Callback;
- public NewAssetRequest(LLUUID assetID, AssetRequestCallback callback)
+ public NewAssetRequest(UUID assetID, AssetRequestCallback callback)
{
AssetID = assetID;
Callback = callback;
diff --git a/OpenSim/Framework/Communications/Cache/AssetServerBase.cs b/OpenSim/Framework/Communications/Cache/AssetServerBase.cs
index 2c8e685..9f4f480 100644
--- a/OpenSim/Framework/Communications/Cache/AssetServerBase.cs
+++ b/OpenSim/Framework/Communications/Cache/AssetServerBase.cs
@@ -28,7 +28,7 @@
using System;
using System.Reflection;
using System.Threading;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
using OpenSim.Framework.AssetLoader.Filesystem;
using OpenSim.Framework.Statistics;
@@ -146,7 +146,7 @@ namespace OpenSim.Framework.Communications.Cache
m_receiver = receiver;
}
- public void RequestAsset(LLUUID assetID, bool isTexture)
+ public void RequestAsset(UUID assetID, bool isTexture)
{
AssetRequest req = new AssetRequest();
req.AssetID = assetID;
diff --git a/OpenSim/Framework/Communications/Cache/CachedUserInfo.cs b/OpenSim/Framework/Communications/Cache/CachedUserInfo.cs
index 8e3be81..339bb31 100644
--- a/OpenSim/Framework/Communications/Cache/CachedUserInfo.cs
+++ b/OpenSim/Framework/Communications/Cache/CachedUserInfo.cs
@@ -30,24 +30,24 @@ using System.Collections.Generic;
using System.Reflection;
using System.Threading;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
namespace OpenSim.Framework.Communications.Cache
{
internal delegate void AddItemDelegate(InventoryItemBase itemInfo);
internal delegate void UpdateItemDelegate(InventoryItemBase itemInfo);
- internal delegate void DeleteItemDelegate(LLUUID itemID);
+ internal delegate void DeleteItemDelegate(UUID itemID);
- internal delegate void CreateFolderDelegate(string folderName, LLUUID folderID, ushort folderType, LLUUID parentID);
- internal delegate void MoveFolderDelegate(LLUUID folderID, LLUUID parentID);
- internal delegate void PurgeFolderDelegate(LLUUID folderID);
- internal delegate void UpdateFolderDelegate(string name, LLUUID folderID, ushort type, LLUUID parentID);
+ internal delegate void CreateFolderDelegate(string folderName, UUID folderID, ushort folderType, UUID parentID);
+ internal delegate void MoveFolderDelegate(UUID folderID, UUID parentID);
+ internal delegate void PurgeFolderDelegate(UUID folderID);
+ internal delegate void UpdateFolderDelegate(string name, UUID folderID, ushort type, UUID parentID);
internal delegate void SendInventoryDescendentsDelegate(
- IClientAPI client, LLUUID folderID, bool fetchFolders, bool fetchItems);
+ IClientAPI client, UUID folderID, bool fetchFolders, bool fetchItems);
- public delegate void OnItemReceivedDelegate(LLUUID itemID);
+ public delegate void OnItemReceivedDelegate(UUID itemID);
///
/// Stores user profile and inventory data received from backend services for a particular user.
@@ -84,12 +84,12 @@ namespace OpenSim.Framework.Communications.Cache
public InventoryFolderImpl RootFolder { get { return m_rootFolder; } }
private InventoryFolderImpl m_rootFolder;
- public LLUUID SessionID
+ public UUID SessionID
{
get { return m_session_id; }
set { m_session_id = value; }
}
- private LLUUID m_session_id = LLUUID.Zero;
+ private UUID m_session_id = UUID.Zero;
///
/// Constructor
@@ -127,9 +127,9 @@ namespace OpenSim.Framework.Communications.Cache
/// Helper function for InventoryReceive() - Store a folder temporarily until we've received entire folder list
///
///
- private void AddFolderToDictionary(InventoryFolderImpl folder, IDictionary> dictionary)
+ private void AddFolderToDictionary(InventoryFolderImpl folder, IDictionary> dictionary)
{
- LLUUID parentFolderId = folder.ParentID;
+ UUID parentFolderId = folder.ParentID;
if (dictionary.ContainsKey(parentFolderId))
dictionary[parentFolderId].Add(folder);
@@ -148,9 +148,9 @@ namespace OpenSim.Framework.Communications.Cache
/// heirarchy
///
///
- /// A
+ /// A
///
- private void ResolveReceivedFolders(InventoryFolderImpl parentFolder, IDictionary> folderDictionary)
+ private void ResolveReceivedFolders(InventoryFolderImpl parentFolder, IDictionary> folderDictionary)
{
if (folderDictionary.ContainsKey(parentFolder.ID))
{
@@ -208,19 +208,19 @@ namespace OpenSim.Framework.Communications.Cache
try
{
// collection of all received folders, indexed by their parent ID
- IDictionary> receivedFolders =
- new Dictionary>();
+ IDictionary> receivedFolders =
+ new Dictionary>();
// Take all received folders, find the root folder, and put ther rest into
// the pendingCategorizationFolders collection
foreach (InventoryFolderImpl folder in folders)
AddFolderToDictionary(folder, receivedFolders);
- if (!receivedFolders.ContainsKey(LLUUID.Zero))
+ if (!receivedFolders.ContainsKey(UUID.Zero))
throw new Exception("Database did not return a root inventory folder");
else
{
- IList rootFolderList = receivedFolders[LLUUID.Zero];
+ IList rootFolderList = receivedFolders[UUID.Zero];
m_rootFolder = rootFolderList[0];
if (rootFolderList.Count > 1)
{
@@ -231,7 +231,7 @@ namespace OpenSim.Framework.Communications.Cache
rootFolderList[i].ID, RootFolder.ID);
}
}
- receivedFolders.Remove(LLUUID.Zero);
+ receivedFolders.Remove(UUID.Zero);
}
// Now take the pendingCategorizationFolders collection, and turn that into a tree,
@@ -240,7 +240,7 @@ namespace OpenSim.Framework.Communications.Cache
ResolveReceivedFolders(RootFolder, receivedFolders);
// Generate a warning for folders that are not part of the heirarchy
- foreach (KeyValuePair> folderList in receivedFolders)
+ foreach (KeyValuePair> folderList in receivedFolders)
{
foreach (InventoryFolderImpl folder in folderList.Value)
m_log.WarnFormat("[INVENTORY CACHE]: Malformed Database: Unresolved Pending Folder {0}", folder.Name);
@@ -314,7 +314,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public bool CreateFolder(string folderName, LLUUID folderID, ushort folderType, LLUUID parentID)
+ public bool CreateFolder(string folderName, UUID folderID, ushort folderType, UUID parentID)
{
// m_log.DebugFormat(
// "[AGENT INVENTORY]: Creating inventory folder {0} {1} for {2} {3}", folderID, folderName, remoteClient.Name, remoteClient.AgentId);
@@ -389,7 +389,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public bool UpdateFolder(string name, LLUUID folderID, ushort type, LLUUID parentID)
+ public bool UpdateFolder(string name, UUID folderID, ushort type, UUID parentID)
{
// m_log.DebugFormat(
// "[AGENT INVENTORY]: Updating inventory folder {0} {1} for {2} {3}", folderID, name, remoteClient.Name, remoteClient.AgentId);
@@ -440,7 +440,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public bool MoveFolder(LLUUID folderID, LLUUID parentID)
+ public bool MoveFolder(UUID folderID, UUID parentID)
{
// m_log.DebugFormat(
// "[AGENT INVENTORY]: Moving inventory folder {0} into folder {1} for {2} {3}",
@@ -487,7 +487,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public bool PurgeFolder(LLUUID folderID)
+ public bool PurgeFolder(UUID folderID)
{
// m_log.InfoFormat("[AGENT INVENTORY]: Purging folder {0} for {1} uuid {2}",
// folderID, remoteClient.Name, remoteClient.AgentId);
@@ -542,7 +542,7 @@ namespace OpenSim.Framework.Communications.Cache
{
if (m_hasReceivedInventory)
{
- if (item.Folder == LLUUID.Zero)
+ if (item.Folder == UUID.Zero)
{
InventoryFolderImpl f = FindFolderForType(item.AssetType);
if (f != null)
@@ -607,7 +607,7 @@ namespace OpenSim.Framework.Communications.Cache
/// true on a successful delete or a if the request is queued.
/// Returns false on an immediate failure
///
- public bool DeleteItem(LLUUID itemID)
+ public bool DeleteItem(UUID itemID)
{
if (m_hasReceivedInventory)
{
@@ -655,7 +655,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// true if the request was queued or successfully processed, false otherwise
- public bool SendInventoryDecendents(IClientAPI client, LLUUID folderID, bool fetchFolders, bool fetchItems)
+ public bool SendInventoryDecendents(IClientAPI client, UUID folderID, bool fetchFolders, bool fetchItems)
{
if (m_hasReceivedInventory)
{
diff --git a/OpenSim/Framework/Communications/Cache/FileAssetClient.cs b/OpenSim/Framework/Communications/Cache/FileAssetClient.cs
index 3c74d4d..e793feb 100644
--- a/OpenSim/Framework/Communications/Cache/FileAssetClient.cs
+++ b/OpenSim/Framework/Communications/Cache/FileAssetClient.cs
@@ -18,11 +18,13 @@ namespace OpenSim.Framework.Communications.Cache
}
public override void StoreAsset(AssetBase asset)
{
- string cdir = m_dir + Path.DirectorySeparatorChar + asset.FullID.Data[0]
- + Path.DirectorySeparatorChar + asset.FullID.Data[1];
+ byte[] idBytes = asset.FullID.Guid.ToByteArray();
- if (!Directory.Exists(m_dir + Path.DirectorySeparatorChar + asset.FullID.Data[0]))
- Directory.CreateDirectory(m_dir + Path.DirectorySeparatorChar + asset.FullID.Data[0]);
+ string cdir = m_dir + Path.DirectorySeparatorChar + idBytes[0]
+ + Path.DirectorySeparatorChar + idBytes[1];
+
+ if (!Directory.Exists(m_dir + Path.DirectorySeparatorChar + idBytes[0]))
+ Directory.CreateDirectory(m_dir + Path.DirectorySeparatorChar + idBytes[0]);
if (!Directory.Exists(cdir))
Directory.CreateDirectory(cdir);
@@ -41,8 +43,10 @@ namespace OpenSim.Framework.Communications.Cache
protected override AssetBase GetAsset(AssetRequest req)
{
- string cdir = m_dir + Path.DirectorySeparatorChar + req.AssetID.Data[0]
- + Path.DirectorySeparatorChar + req.AssetID.Data[1];
+ byte[] idBytes = req.AssetID.Guid.ToByteArray();
+
+ string cdir = m_dir + Path.DirectorySeparatorChar + idBytes[0]
+ + Path.DirectorySeparatorChar + idBytes[1];
if (File.Exists(cdir + Path.DirectorySeparatorChar + req.AssetID + ".xml"))
{
FileStream x = File.OpenRead(cdir + Path.DirectorySeparatorChar + req.AssetID + ".xml");
diff --git a/OpenSim/Framework/Communications/Cache/InventoryFolderImpl.cs b/OpenSim/Framework/Communications/Cache/InventoryFolderImpl.cs
index 61cfc1a..debcbfb 100644
--- a/OpenSim/Framework/Communications/Cache/InventoryFolderImpl.cs
+++ b/OpenSim/Framework/Communications/Cache/InventoryFolderImpl.cs
@@ -27,7 +27,7 @@
using System;
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
//using System.Reflection;
//using log4net;
@@ -43,12 +43,12 @@ namespace OpenSim.Framework.Communications.Cache
///
/// Items that are contained in this folder
///
- public Dictionary Items = new Dictionary();
+ public Dictionary Items = new Dictionary();
///
/// Child folders that are contained in this folder
///
- public Dictionary SubFolders = new Dictionary();
+ public Dictionary SubFolders = new Dictionary();
// Constructors
public InventoryFolderImpl(InventoryFolderBase folderbase)
@@ -72,7 +72,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// The newly created subfolder. Returns null if the folder already exists
- public InventoryFolderImpl CreateChildFolder(LLUUID folderID, string folderName, ushort type)
+ public InventoryFolderImpl CreateChildFolder(UUID folderID, string folderName, ushort type)
{
lock (SubFolders)
{
@@ -112,7 +112,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// null if the item is not found
- public InventoryItemBase FindItem(LLUUID itemID)
+ public InventoryItemBase FindItem(UUID itemID)
{
lock (Items)
{
@@ -143,7 +143,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public bool DeleteItem(LLUUID itemID)
+ public bool DeleteItem(UUID itemID)
{
bool found = false;
@@ -177,7 +177,7 @@ namespace OpenSim.Framework.Communications.Cache
/// first.
///
/// The requested folder if it exists, null if it does not.
- public InventoryFolderImpl FindFolder(LLUUID folderID)
+ public InventoryFolderImpl FindFolder(UUID folderID)
{
if (folderID == ID)
return this;
diff --git a/OpenSim/Framework/Communications/Cache/LibraryRootFolder.cs b/OpenSim/Framework/Communications/Cache/LibraryRootFolder.cs
index 1ff6350..7e561b5 100644
--- a/OpenSim/Framework/Communications/Cache/LibraryRootFolder.cs
+++ b/OpenSim/Framework/Communications/Cache/LibraryRootFolder.cs
@@ -30,7 +30,7 @@ using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Xml;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
using Nini.Config;
@@ -44,29 +44,29 @@ namespace OpenSim.Framework.Communications.Cache
{
private static readonly ILog m_log = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);
- private LLUUID libOwner = new LLUUID("11111111-1111-0000-0000-000100bba000");
+ private UUID libOwner = new UUID("11111111-1111-0000-0000-000100bba000");
///
/// Holds the root library folder and all its descendents. This is really only used during inventory
/// setup so that we don't have to repeatedly search the tree of library folders.
///
- protected Dictionary libraryFolders
- = new Dictionary();
+ protected Dictionary libraryFolders
+ = new Dictionary();
public LibraryRootFolder()
{
m_log.Info("[LIBRARY INVENTORY]: Loading library inventory");
Owner = libOwner;
- ID = new LLUUID("00000112-000f-0000-0000-000100bba000");
+ ID = new UUID("00000112-000f-0000-0000-000100bba000");
Name = "OpenSim Library";
- ParentID = LLUUID.Zero;
+ ParentID = UUID.Zero;
Type = (short) 8;
Version = (ushort) 1;
libraryFolders.Add(ID, this);
- LoadLibraries(Path.Combine(Util.inventoryDir(), "Libraries.xml"));
+ LoadLibraries(Path.Combine(Util.inventoryDir(), "Libraries.Xml"));
// CreateLibraryItems();
}
@@ -81,40 +81,40 @@ namespace OpenSim.Framework.Communications.Cache
//private void CreateLibraryItems()
//{
// InventoryItemBase item =
- // CreateItem(new LLUUID("66c41e39-38f9-f75a-024e-585989bfaba9"),
- // new LLUUID("66c41e39-38f9-f75a-024e-585989bfab73"), "Default Shape", "Default Shape",
+ // CreateItem(new UUID("66c41e39-38f9-f75a-024e-585989bfaba9"),
+ // new UUID("66c41e39-38f9-f75a-024e-585989bfab73"), "Default Shape", "Default Shape",
// (int) AssetType.Bodypart, (int) InventoryType.Wearable, folderID);
// item.inventoryCurrentPermissions = 0;
// item.inventoryNextPermissions = 0;
// Items.Add(item.inventoryID, item);
// item =
- // CreateItem(new LLUUID("77c41e39-38f9-f75a-024e-585989bfabc9"),
- // new LLUUID("77c41e39-38f9-f75a-024e-585989bbabbb"), "Default Skin", "Default Skin",
+ // CreateItem(new UUID("77c41e39-38f9-f75a-024e-585989bfabc9"),
+ // new UUID("77c41e39-38f9-f75a-024e-585989bbabbb"), "Default Skin", "Default Skin",
// (int) AssetType.Bodypart, (int) InventoryType.Wearable, folderID);
// item.inventoryCurrentPermissions = 0;
// item.inventoryNextPermissions = 0;
// Items.Add(item.inventoryID, item);
// item =
- // CreateItem(new LLUUID("77c41e39-38f9-f75a-0000-585989bf0000"),
- // new LLUUID("00000000-38f9-1111-024e-222222111110"), "Default Shirt", "Default Shirt",
+ // CreateItem(new UUID("77c41e39-38f9-f75a-0000-585989bf0000"),
+ // new UUID("00000000-38f9-1111-024e-222222111110"), "Default Shirt", "Default Shirt",
// (int) AssetType.Clothing, (int) InventoryType.Wearable, folderID);
// item.inventoryCurrentPermissions = 0;
// item.inventoryNextPermissions = 0;
// Items.Add(item.inventoryID, item);
// item =
- // CreateItem(new LLUUID("77c41e39-38f9-f75a-0000-5859892f1111"),
- // new LLUUID("00000000-38f9-1111-024e-222222111120"), "Default Pants", "Default Pants",
+ // CreateItem(new UUID("77c41e39-38f9-f75a-0000-5859892f1111"),
+ // new UUID("00000000-38f9-1111-024e-222222111120"), "Default Pants", "Default Pants",
// (int) AssetType.Clothing, (int) InventoryType.Wearable, folderID);
// item.inventoryCurrentPermissions = 0;
// item.inventoryNextPermissions = 0;
// Items.Add(item.inventoryID, item);
//}
- public InventoryItemBase CreateItem(LLUUID inventoryID, LLUUID assetID, string name, string description,
- int assetType, int invType, LLUUID parentFolderID)
+ public InventoryItemBase CreateItem(UUID inventoryID, UUID assetID, string name, string description,
+ int assetType, int invType, UUID parentFolderID)
{
InventoryItemBase item = new InventoryItemBase();
item.Owner = libOwner;
@@ -173,9 +173,9 @@ namespace OpenSim.Framework.Communications.Cache
{
InventoryFolderImpl folderInfo = new InventoryFolderImpl();
- folderInfo.ID = new LLUUID(config.GetString("folderID", ID.ToString()));
+ folderInfo.ID = new UUID(config.GetString("folderID", ID.ToString()));
folderInfo.Name = config.GetString("name", "unknown");
- folderInfo.ParentID = new LLUUID(config.GetString("parentFolderID", ID.ToString()));
+ folderInfo.ParentID = new UUID(config.GetString("parentFolderID", ID.ToString()));
folderInfo.Type = (short)config.GetInt("type", 8);
folderInfo.Owner = libOwner;
@@ -207,9 +207,9 @@ namespace OpenSim.Framework.Communications.Cache
InventoryItemBase item = new InventoryItemBase();
item.Owner = libOwner;
item.Creator = libOwner;
- item.ID = new LLUUID(config.GetString("inventoryID", ID.ToString()));
- item.AssetID = new LLUUID(config.GetString("assetID", item.ID.ToString()));
- item.Folder = new LLUUID(config.GetString("folderID", ID.ToString()));
+ item.ID = new UUID(config.GetString("inventoryID", ID.ToString()));
+ item.AssetID = new UUID(config.GetString("assetID", item.ID.ToString()));
+ item.Folder = new UUID(config.GetString("folderID", ID.ToString()));
item.Name = config.GetString("name", String.Empty);
item.Description = config.GetString("description", item.Name);
item.InvType = config.GetInt("inventoryType", 0);
@@ -270,7 +270,7 @@ namespace OpenSim.Framework.Communications.Cache
/// methods in the superclass
///
///
- public Dictionary RequestSelfAndDescendentFolders()
+ public Dictionary RequestSelfAndDescendentFolders()
{
return libraryFolders;
}
diff --git a/OpenSim/Framework/Communications/Cache/UserProfileCacheService.cs b/OpenSim/Framework/Communications/Cache/UserProfileCacheService.cs
index 45f6c7e..3675053 100644
--- a/OpenSim/Framework/Communications/Cache/UserProfileCacheService.cs
+++ b/OpenSim/Framework/Communications/Cache/UserProfileCacheService.cs
@@ -29,7 +29,7 @@ using System;
using System.Collections.Generic;
using System.Reflection;
using System.Threading;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
namespace OpenSim.Framework.Communications.Cache
@@ -49,7 +49,7 @@ namespace OpenSim.Framework.Communications.Cache
///
/// Each user has a cached profile.
///
- private readonly Dictionary m_userProfiles = new Dictionary();
+ private readonly Dictionary m_userProfiles = new Dictionary();
public readonly LibraryRootFolder libraryRoot = new LibraryRootFolder();
@@ -63,9 +63,9 @@ namespace OpenSim.Framework.Communications.Cache
/// A new user has moved into a region in this instance so retrieve their profile from the user service.
///
///
- public void AddNewUser(LLUUID userID)
+ public void AddNewUser(UUID userID)
{
- if (userID == LLUUID.Zero)
+ if (userID == UUID.Zero)
return;
m_log.DebugFormat("[USER CACHE]: Adding user profile for {0}", userID);
GetUserDetails(userID);
@@ -76,7 +76,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// true if the user was successfully removed, false otherwise
- public bool RemoveUser(LLUUID userId)
+ public bool RemoveUser(UUID userId)
{
lock (m_userProfiles)
{
@@ -99,7 +99,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void RequestInventoryForUser(LLUUID userID)
+ public void RequestInventoryForUser(UUID userID)
{
CachedUserInfo userInfo = GetUserDetails(userID);
if (userInfo != null)
@@ -130,9 +130,9 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// null if no user details are found
- public CachedUserInfo GetUserDetails(LLUUID userID)
+ public CachedUserInfo GetUserDetails(UUID userID)
{
- if (userID == LLUUID.Zero)
+ if (userID == UUID.Zero)
return null;
lock (m_userProfiles)
@@ -164,9 +164,9 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void PreloadUserCache(LLUUID userID, UserProfileData userData)
+ public void PreloadUserCache(UUID userID, UserProfileData userData)
{
- if (userID == LLUUID.Zero)
+ if (userID == UUID.Zero)
return;
lock (m_userProfiles)
@@ -192,8 +192,8 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void HandleCreateInventoryFolder(IClientAPI remoteClient, LLUUID folderID, ushort folderType,
- string folderName, LLUUID parentID)
+ public void HandleCreateInventoryFolder(IClientAPI remoteClient, UUID folderID, ushort folderType,
+ string folderName, UUID parentID)
{
CachedUserInfo userProfile;
@@ -226,8 +226,8 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void HandleUpdateInventoryFolder(IClientAPI remoteClient, LLUUID folderID, ushort type, string name,
- LLUUID parentID)
+ public void HandleUpdateInventoryFolder(IClientAPI remoteClient, UUID folderID, ushort type, string name,
+ UUID parentID)
{
// m_log.DebugFormat(
// "[AGENT INVENTORY]: Updating inventory folder {0} {1} for {2} {3}", folderID, name, remoteClient.Name, remoteClient.AgentId);
@@ -257,7 +257,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void HandleMoveInventoryFolder(IClientAPI remoteClient, LLUUID folderID, LLUUID parentID)
+ public void HandleMoveInventoryFolder(IClientAPI remoteClient, UUID folderID, UUID parentID)
{
CachedUserInfo userProfile;
@@ -287,7 +287,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void HandleFetchInventoryDescendents(IClientAPI remoteClient, LLUUID folderID, LLUUID ownerID,
+ public void HandleFetchInventoryDescendents(IClientAPI remoteClient, UUID folderID, UUID ownerID,
bool fetchFolders, bool fetchItems, int sortOrder)
{
// FIXME MAYBE: We're not handling sortOrder!
@@ -327,7 +327,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
/// null if the inventory look up failed
- public List HandleFetchInventoryDescendentsCAPS(LLUUID agentID, LLUUID folderID, LLUUID ownerID,
+ public List HandleFetchInventoryDescendentsCAPS(UUID agentID, UUID folderID, UUID ownerID,
bool fetchFolders, bool fetchItems, int sortOrder)
{
// m_log.DebugFormat(
@@ -405,7 +405,7 @@ namespace OpenSim.Framework.Communications.Cache
///
///
///
- public void HandlePurgeInventoryDescendents(IClientAPI remoteClient, LLUUID folderID)
+ public void HandlePurgeInventoryDescendents(IClientAPI remoteClient, UUID folderID)
{
CachedUserInfo userProfile;
@@ -426,7 +426,7 @@ namespace OpenSim.Framework.Communications.Cache
}
}
- public void HandleFetchInventory(IClientAPI remoteClient, LLUUID itemID, LLUUID ownerID)
+ public void HandleFetchInventory(IClientAPI remoteClient, UUID itemID, UUID ownerID)
{
if (ownerID == libraryRoot.Owner)
{
diff --git a/OpenSim/Framework/Communications/Capabilities/Caps.cs b/OpenSim/Framework/Communications/Capabilities/Caps.cs
index a7486d6..e82a5e9 100644
--- a/OpenSim/Framework/Communications/Capabilities/Caps.cs
+++ b/OpenSim/Framework/Communications/Capabilities/Caps.cs
@@ -30,7 +30,7 @@ using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Reflection;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
using OpenSim.Framework.Communications.Cache;
using OpenSim.Framework.Servers;
@@ -40,21 +40,21 @@ using OpenSim.Region.Interfaces;
namespace OpenSim.Framework.Communications.Capabilities
{
public delegate void UpLoadedAsset(
- string assetName, string description, LLUUID assetID, LLUUID inventoryItem, LLUUID parentFolder,
+ string assetName, string description, UUID assetID, UUID inventoryItem, UUID parentFolder,
byte[] data, string inventoryType, string assetType);
- public delegate LLUUID UpdateItem(LLUUID itemID, byte[] data);
+ public delegate UUID UpdateItem(UUID itemID, byte[] data);
- public delegate void UpdateTaskScript(LLUUID itemID, LLUUID primID, bool isScriptRunning, byte[] data);
+ public delegate void UpdateTaskScript(UUID itemID, UUID primID, bool isScriptRunning, byte[] data);
- public delegate void NewInventoryItem(LLUUID userID, InventoryItemBase item);
+ public delegate void NewInventoryItem(UUID userID, InventoryItemBase item);
- public delegate LLUUID ItemUpdatedCallback(LLUUID userID, LLUUID itemID, byte[] data);
+ public delegate UUID ItemUpdatedCallback(UUID userID, UUID itemID, byte[] data);
- public delegate void TaskScriptUpdatedCallback(LLUUID userID, LLUUID itemID, LLUUID primID,
+ public delegate void TaskScriptUpdatedCallback(UUID userID, UUID itemID, UUID primID,
bool isScriptRunning, byte[] data);
- public delegate List FetchInventoryDescendentsCAPS(LLUUID agentID, LLUUID folderID, LLUUID ownerID,
+ public delegate List FetchInventoryDescendentsCAPS(UUID agentID, UUID folderID, UUID ownerID,
bool fetchFolders, bool fetchItems, int sortOrder);
///
@@ -62,7 +62,7 @@ namespace OpenSim.Framework.Communications.Capabilities
/// we can popup a message on the user's client if the inventory service has permanently failed). But I didn't want
/// to just pass the whole Scene into CAPS.
///
- public delegate IClientAPI GetClientDelegate(LLUUID agentID);
+ public delegate IClientAPI GetClientDelegate(UUID agentID);
public class Caps
{
@@ -97,7 +97,7 @@ namespace OpenSim.Framework.Communications.Capabilities
//private string eventQueue = "0100/";
private BaseHttpServer m_httpListener;
- private LLUUID m_agentID;
+ private UUID m_agentID;
private AssetCache m_assetCache;
private int m_eventQueueCount = 1;
private Queue m_capsEventQueue = new Queue();
@@ -113,7 +113,7 @@ namespace OpenSim.Framework.Communications.Capabilities
public GetClientDelegate GetClient = null;
public Caps(AssetCache assetCache, BaseHttpServer httpServer, string httpListen, uint httpPort, string capsPath,
- LLUUID agent, bool dumpAssetsToFile, string regionName)
+ UUID agent, bool dumpAssetsToFile, string regionName)
{
m_assetCache = assetCache;
m_capsObjectPath = capsPath;
@@ -258,7 +258,7 @@ namespace OpenSim.Framework.Communications.Capabilities
Hashtable hash = new Hashtable();
try
{
- hash = (Hashtable)LLSD.LLSDDeserialize(Helpers.StringToField(request));
+ hash = (Hashtable)LLSD.LLSDDeserialize(Utils.StringToBytes(request));
}
catch (LLSD.LLSDParseException pe)
{
@@ -388,7 +388,7 @@ namespace OpenSim.Framework.Communications.Capabilities
llsdItem.permissions.creator_id = invItem.Creator;
llsdItem.permissions.base_mask = (int)invItem.CurrentPermissions;
llsdItem.permissions.everyone_mask = (int)invItem.EveryOnePermissions;
- llsdItem.permissions.group_id = LLUUID.Zero;
+ llsdItem.permissions.group_id = UUID.Zero;
llsdItem.permissions.group_mask = 0;
llsdItem.permissions.is_owner_group = false;
llsdItem.permissions.next_owner_mask = (int)invItem.NextPermissions;
@@ -423,7 +423,7 @@ namespace OpenSim.Framework.Communications.Capabilities
LLSDMapLayer mapLayer = new LLSDMapLayer();
mapLayer.Right = 5000;
mapLayer.Top = 5000;
- mapLayer.ImageID = new LLUUID("00000000-0000-1111-9999-000000000006");
+ mapLayer.ImageID = new UUID("00000000-0000-1111-9999-000000000006");
return mapLayer;
}
@@ -522,7 +522,7 @@ namespace OpenSim.Framework.Communications.Capabilities
m_log.Debug("[CAPS]: ScriptTaskInventory Request in region: " + m_regionName);
//m_log.DebugFormat("[CAPS]: request: {0}, path: {1}, param: {2}", request, path, param);
- Hashtable hash = (Hashtable) LLSD.LLSDDeserialize(Helpers.StringToField(request));
+ Hashtable hash = (Hashtable) LLSD.LLSDDeserialize(Utils.StringToBytes(request));
LLSDTaskScriptUpdate llsdUpdateRequest = new LLSDTaskScriptUpdate();
LLSDHelpers.DeserialiseLLSDMap(hash, llsdUpdateRequest);
@@ -573,8 +573,8 @@ namespace OpenSim.Framework.Communications.Capabilities
OSHttpRequest httpRequest, OSHttpResponse httpResponse)
{
m_log.Debug("[CAPS]: NoteCardAgentInventory Request in region: " + m_regionName);
- //libsecondlife.StructuredData.LLSDMap hash = (libsecondlife.StructuredData.LLSDMap)libsecondlife.StructuredData.LLSDParser.DeserializeBinary(Helpers.StringToField(request));
- Hashtable hash = (Hashtable) LLSD.LLSDDeserialize(Helpers.StringToField(request));
+ //OpenMetaverse.StructuredData.LLSDMap hash = (OpenMetaverse.StructuredData.LLSDMap)OpenMetaverse.StructuredData.LLSDParser.DeserializeBinary(Utils.StringToBytes(request));
+ Hashtable hash = (Hashtable) LLSD.LLSDDeserialize(Utils.StringToBytes(request));
LLSDItemUpdate llsdRequest = new LLSDItemUpdate();
LLSDHelpers.DeserialiseLLSDMap(hash, llsdRequest);
@@ -636,9 +636,9 @@ namespace OpenSim.Framework.Communications.Capabilities
string assetName = llsdRequest.name;
string assetDes = llsdRequest.description;
string capsBase = "/CAPS/" + m_capsObjectPath;
- LLUUID newAsset = LLUUID.Random();
- LLUUID newInvItem = LLUUID.Random();
- LLUUID parentFolder = llsdRequest.folder_id;
+ UUID newAsset = UUID.Random();
+ UUID newInvItem = UUID.Random();
+ UUID parentFolder = llsdRequest.folder_id;
string uploaderPath = Util.RandomClass.Next(5000, 8000).ToString("0000");
AssetUploader uploader =
@@ -662,8 +662,8 @@ namespace OpenSim.Framework.Communications.Capabilities
///
///
///
- public void UploadCompleteHandler(string assetName, string assetDescription, LLUUID assetID,
- LLUUID inventoryItem, LLUUID parentFolder, byte[] data, string inventoryType,
+ public void UploadCompleteHandler(string assetName, string assetDescription, UUID assetID,
+ UUID inventoryItem, UUID parentFolder, byte[] data, string inventoryType,
string assetType)
{
sbyte assType = 0;
@@ -728,14 +728,14 @@ namespace OpenSim.Framework.Communications.Capabilities
/// Item to update
/// New asset data
///
- public LLUUID ItemUpdated(LLUUID itemID, byte[] data)
+ public UUID ItemUpdated(UUID itemID, byte[] data)
{
if (ItemUpdatedCall != null)
{
return ItemUpdatedCall(m_agentID, itemID, data);
}
- return LLUUID.Zero;
+ return UUID.Zero;
}
///
@@ -745,7 +745,7 @@ namespace OpenSim.Framework.Communications.Capabilities
/// Prim containing item to update
/// Signals whether the script to update is currently running
/// New asset data
- public void TaskScriptUpdated(LLUUID itemID, LLUUID primID, bool isScriptRunning, byte[] data)
+ public void TaskScriptUpdated(UUID itemID, UUID primID, bool isScriptRunning, byte[] data)
{
if (TaskScriptUpdatedCall != null)
{
@@ -759,9 +759,9 @@ namespace OpenSim.Framework.Communications.Capabilities
private UpLoadedAsset handlerUpLoad = null;
private string uploaderPath = String.Empty;
- private LLUUID newAssetID;
- private LLUUID inventoryItemID;
- private LLUUID parentFolder;
+ private UUID newAssetID;
+ private UUID inventoryItemID;
+ private UUID parentFolder;
private BaseHttpServer httpListener;
private bool m_dumpAssetsToFile;
private string m_assetName = String.Empty;
@@ -770,8 +770,8 @@ namespace OpenSim.Framework.Communications.Capabilities
private string m_invType = String.Empty;
private string m_assetType = String.Empty;
- public AssetUploader(string assetName, string description, LLUUID assetID, LLUUID inventoryItem,
- LLUUID parentFolderID, string invType, string assetType, string path,
+ public AssetUploader(string assetName, string description, UUID assetID, UUID inventoryItem,
+ UUID parentFolderID, string invType, string assetType, string path,
BaseHttpServer httpServer, bool dumpAssetsToFile)
{
m_assetName = assetName;
@@ -795,7 +795,7 @@ namespace OpenSim.Framework.Communications.Capabilities
///
public string uploaderCaps(byte[] data, string path, string param)
{
- LLUUID inv = inventoryItemID;
+ UUID inv = inventoryItemID;
string res = String.Empty;
LLSDAssetUploadComplete uploadComplete = new LLSDAssetUploadComplete();
uploadComplete.new_asset = newAssetID.ToString();
@@ -860,11 +860,11 @@ namespace OpenSim.Framework.Communications.Capabilities
private UpdateItem handlerUpdateItem = null;
private string uploaderPath = String.Empty;
- private LLUUID inventoryItemID;
+ private UUID inventoryItemID;
private BaseHttpServer httpListener;
private bool m_dumpAssetToFile;
- public ItemUpdater(LLUUID inventoryItem, string path, BaseHttpServer httpServer, bool dumpAssetToFile)
+ public ItemUpdater(UUID inventoryItem, string path, BaseHttpServer httpServer, bool dumpAssetToFile)
{
m_dumpAssetToFile = dumpAssetToFile;
@@ -882,10 +882,10 @@ namespace OpenSim.Framework.Communications.Capabilities
///
public string uploaderCaps(byte[] data, string path, string param)
{
- LLUUID inv = inventoryItemID;
+ UUID inv = inventoryItemID;
string res = String.Empty;
LLSDAssetUploadComplete uploadComplete = new LLSDAssetUploadComplete();
- LLUUID assetID = LLUUID.Zero;
+ UUID assetID = UUID.Zero;
handlerUpdateItem = OnUpLoad;
if (handlerUpdateItem != null)
{
@@ -942,13 +942,13 @@ namespace OpenSim.Framework.Communications.Capabilities
private UpdateTaskScript handlerUpdateTaskScript = null;
private string uploaderPath = String.Empty;
- private LLUUID inventoryItemID;
- private LLUUID primID;
+ private UUID inventoryItemID;
+ private UUID primID;
private bool isScriptRunning;
private BaseHttpServer httpListener;
private bool m_dumpAssetToFile;
- public TaskInventoryScriptUpdater(LLUUID inventoryItemID, LLUUID primID, int isScriptRunning,
+ public TaskInventoryScriptUpdater(UUID inventoryItemID, UUID primID, int isScriptRunning,
string path, BaseHttpServer httpServer, bool dumpAssetToFile)
{
m_dumpAssetToFile = dumpAssetToFile;
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSD.cs b/OpenSim/Framework/Communications/Capabilities/LLSD.cs
index aa9951c..44c4a05 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSD.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSD.cs
@@ -32,7 +32,7 @@ using System.IO;
using System.Security.Cryptography;
using System.Text;
using System.Xml;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -158,9 +158,9 @@ namespace OpenSim.Framework.Communications.Capabilities
{
throw new Exception("ulong in LLSD is currently not implemented, fix me!");
}
- else if (obj is LLUUID)
+ else if (obj is UUID)
{
- LLUUID u = (LLUUID) obj;
+ UUID u = (UUID) obj;
writer.WriteStartElement(String.Empty, "uuid", String.Empty);
writer.WriteString(u.ToString());
writer.WriteEndElement();
@@ -294,11 +294,11 @@ namespace OpenSim.Framework.Communications.Capabilities
if (reader.IsEmptyElement)
{
reader.Read();
- return LLUUID.Zero;
+ return UUID.Zero;
}
reader.Read();
- ret = new LLUUID(reader.ReadString().Trim());
+ ret = new UUID(reader.ReadString().Trim());
break;
}
case "string":
@@ -476,9 +476,9 @@ namespace OpenSim.Framework.Communications.Capabilities
{
return GetSpaces(indent) + "- float " + obj.ToString() + "\n";
}
- else if (obj is LLUUID)
+ else if (obj is UUID)
{
- return GetSpaces(indent) + "- uuid " + ((LLUUID) obj).ToString() + Environment.NewLine;
+ return GetSpaces(indent) + "- uuid " + ((UUID) obj).ToString() + Environment.NewLine;
}
else if (obj is Hashtable)
{
@@ -509,7 +509,7 @@ namespace OpenSim.Framework.Communications.Capabilities
}
else if (obj is byte[])
{
- return GetSpaces(indent) + "- binary\n" + Helpers.FieldToHexString((byte[]) obj, GetSpaces(indent)) +
+ return GetSpaces(indent) + "- binary\n" + Utils.BytesToHexString((byte[]) obj, GetSpaces(indent)) +
Environment.NewLine;
}
else
@@ -568,14 +568,14 @@ namespace OpenSim.Framework.Communications.Capabilities
}
case 'u':
{
- if (llsd.Length < 17) throw new LLSDParseException("LLUUID value type with no value");
- LLUUID value;
+ if (llsd.Length < 17) throw new LLSDParseException("UUID value type with no value");
+ UUID value;
endPos = FindEnd(llsd, 1);
- if (LLUUID.TryParse(llsd.Substring(1, endPos - 1), out value))
+ if (UUID.TryParse(llsd.Substring(1, endPos - 1), out value))
return value;
else
- throw new LLSDParseException("Failed to parse LLUUID value type");
+ throw new LLSDParseException("Failed to parse UUID value type");
}
case 'b':
//byte[] value = new byte[llsd.Length - 1];
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadComplete.cs b/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadComplete.cs
index 6c4db4b..680dcc8 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadComplete.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadComplete.cs
@@ -26,7 +26,7 @@
*/
using System;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -34,7 +34,7 @@ namespace OpenSim.Framework.Communications.Capabilities
public class LLSDAssetUploadComplete
{
public string new_asset = String.Empty;
- public LLUUID new_inventory_item = LLUUID.Zero;
+ public UUID new_inventory_item = UUID.Zero;
public string state = String.Empty;
//public bool success = false;
@@ -42,4 +42,4 @@ namespace OpenSim.Framework.Communications.Capabilities
{
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadRequest.cs b/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadRequest.cs
index 289cc93..5833b65 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadRequest.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDAssetUploadRequest.cs
@@ -26,7 +26,7 @@
*/
using System;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -35,7 +35,7 @@ namespace OpenSim.Framework.Communications.Capabilities
{
public string asset_type = String.Empty;
public string description = String.Empty;
- public LLUUID folder_id = LLUUID.Zero;
+ public UUID folder_id = UUID.Zero;
public string inventory_type = String.Empty;
public string name = String.Empty;
@@ -43,4 +43,4 @@ namespace OpenSim.Framework.Communications.Capabilities
{
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDHelpers.cs b/OpenSim/Framework/Communications/Capabilities/LLSDHelpers.cs
index 507f12b..b14bfdd 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDHelpers.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDHelpers.cs
@@ -86,8 +86,8 @@ namespace OpenSim.Framework.Communications.Capabilities
writer.WriteString(fieldName);
writer.WriteEndElement();
LLSD.LLSDWriteOne(writer, fieldValue);
- // libsecondlife.StructuredData.LLSDParser.SerializeXmlElement(
- // writer, libsecondlife.StructuredData.LLSD.FromObject(fieldValue));
+ // OpenMetaverse.StructuredData.LLSDParser.SerializeXmlElement(
+ // writer, OpenMetaverse.StructuredData.LLSD.FromObject(fieldValue));
}
}
writer.WriteEndElement();
@@ -111,8 +111,8 @@ namespace OpenSim.Framework.Communications.Capabilities
else
{
LLSD.LLSDWriteOne(writer, obj);
- //libsecondlife.StructuredData.LLSDParser.SerializeXmlElement(
- // writer, libsecondlife.StructuredData.LLSD.FromObject(obj));
+ //OpenMetaverse.StructuredData.LLSDParser.SerializeXmlElement(
+ // writer, OpenMetaverse.StructuredData.LLSD.FromObject(obj));
}
}
@@ -133,12 +133,12 @@ namespace OpenSim.Framework.Communications.Capabilities
FieldInfo field = myType.GetField(keyName);
if (field != null)
{
- // if (enumerator.Value is libsecondlife.StructuredData.LLSDMap)
+ // if (enumerator.Value is OpenMetaverse.StructuredData.LLSDMap)
if (enumerator.Value is Hashtable)
{
object fieldValue = field.GetValue(obj);
DeserialiseLLSDMap((Hashtable) enumerator.Value, fieldValue);
- // DeserialiseLLSDMap((libsecondlife.StructuredData.LLSDMap) enumerator.Value, fieldValue);
+ // DeserialiseLLSDMap((OpenMetaverse.StructuredData.LLSDMap) enumerator.Value, fieldValue);
}
else if (enumerator.Value is ArrayList)
{
@@ -160,4 +160,4 @@ namespace OpenSim.Framework.Communications.Capabilities
return obj;
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDInventoryItem.cs b/OpenSim/Framework/Communications/Capabilities/LLSDInventoryItem.cs
index 1a75aba..ff36821 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDInventoryItem.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDInventoryItem.cs
@@ -25,17 +25,17 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
[LLSDMap]
public class LLSDInventoryItem
{
- public LLUUID parent_id;
+ public UUID parent_id;
- public LLUUID asset_id;
- public LLUUID item_id;
+ public UUID asset_id;
+ public UUID item_id;
public LLSDPermissions permissions;
public string type;
public string inv_type;
@@ -50,9 +50,9 @@ namespace OpenSim.Framework.Communications.Capabilities
[LLSDMap]
public class LLSDPermissions
{
- public LLUUID creator_id;
- public LLUUID owner_id;
- public LLUUID group_id;
+ public UUID creator_id;
+ public UUID owner_id;
+ public UUID group_id;
public int base_mask;
public int owner_mask;
public int group_mask;
@@ -77,8 +77,8 @@ namespace OpenSim.Framework.Communications.Capabilities
[LLSDMap]
public class LLSDFetchInventoryDescendents
{
- public LLUUID folder_id;
- public LLUUID owner_id;
+ public UUID folder_id;
+ public UUID owner_id;
public int sort_order;
public bool fetch_folders;
public bool fetch_items;
@@ -87,11 +87,11 @@ namespace OpenSim.Framework.Communications.Capabilities
[LLSDMap]
public class LLSDInventoryFolderContents
{
- public LLUUID agent___id; // the (three "_") "___" so the serialising knows to change this to a "-"
+ public UUID agent___id; // the (three "_") "___" so the serialising knows to change this to a "-"
public int descendents;
- public LLUUID folder___id; //as LL can't decide if they are going to use "_" or "-" to separate words in the field names
+ public UUID folder___id; //as LL can't decide if they are going to use "_" or "-" to separate words in the field names
public LLSDArray items = new LLSDArray();
- public LLUUID owner___id; // and of course we can't have field names with "-" in
+ public UUID owner___id; // and of course we can't have field names with "-" in
public int version;
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDItemUpdate.cs b/OpenSim/Framework/Communications/Capabilities/LLSDItemUpdate.cs
index 2c4b68f..c147bd3 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDItemUpdate.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDItemUpdate.cs
@@ -25,17 +25,17 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
[LLSDMap]
public class LLSDItemUpdate
{
- public LLUUID item_id;
+ public UUID item_id;
public LLSDItemUpdate()
{
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDMapLayer.cs b/OpenSim/Framework/Communications/Capabilities/LLSDMapLayer.cs
index 50f5241..fc381e4 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDMapLayer.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDMapLayer.cs
@@ -25,7 +25,7 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -36,10 +36,10 @@ namespace OpenSim.Framework.Communications.Capabilities
public int Right = 0;
public int Top = 0;
public int Bottom = 0;
- public LLUUID ImageID = LLUUID.Zero;
+ public UUID ImageID = UUID.Zero;
public LLSDMapLayer()
{
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDRemoteParcelResponse.cs b/OpenSim/Framework/Communications/Capabilities/LLSDRemoteParcelResponse.cs
index b0e2b8f..1220089 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDRemoteParcelResponse.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDRemoteParcelResponse.cs
@@ -26,14 +26,14 @@
*
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
[LLSDType("MAP")]
public class LLSDRemoteParcelResponse
{
- public LLUUID parcel_id;
+ public UUID parcel_id;
public LLSDRemoteParcelResponse()
{
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDStreamHandler.cs b/OpenSim/Framework/Communications/Capabilities/LLSDStreamHandler.cs
index 36090e1..7fcbb81 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDStreamHandler.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDStreamHandler.cs
@@ -53,8 +53,8 @@ namespace OpenSim.Framework.Communications.Capabilities
//string requestBody = streamReader.ReadToEnd();
//streamReader.Close();
- // libsecondlife.StructuredData.LLSDMap hash = (libsecondlife.StructuredData.LLSDMap)
- // libsecondlife.StructuredData.LLSDParser.DeserializeXml(new XmlTextReader(request));
+ // OpenMetaverse.StructuredData.LLSDMap hash = (OpenMetaverse.StructuredData.LLSDMap)
+ // OpenMetaverse.StructuredData.LLSDParser.DeserializeXml(new XmlTextReader(request));
Hashtable hash = (Hashtable) LLSD.LLSDDeserialize(request);
TRequest llsdRequest = new TRequest();
@@ -67,4 +67,4 @@ namespace OpenSim.Framework.Communications.Capabilities
return encoding.GetBytes(LLSDHelpers.SerialiseLLSDReply(response));
}
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDTaskInventoryUploadComplete.cs b/OpenSim/Framework/Communications/Capabilities/LLSDTaskInventoryUploadComplete.cs
index 8bfd20c..b34cbf9 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDTaskInventoryUploadComplete.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDTaskInventoryUploadComplete.cs
@@ -25,7 +25,7 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -35,16 +35,16 @@ namespace OpenSim.Framework.Communications.Capabilities
///
/// The task inventory item that was updated
///
- public LLUUID item_id;
+ public UUID item_id;
///
/// The task that was updated
///
- public LLUUID task_id;
+ public UUID task_id;
///
/// State of the upload. So far have only even seen this set to "complete"
///
public string state;
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/Capabilities/LLSDTaskScriptUpdate.cs b/OpenSim/Framework/Communications/Capabilities/LLSDTaskScriptUpdate.cs
index e45d9de..730e95b 100644
--- a/OpenSim/Framework/Communications/Capabilities/LLSDTaskScriptUpdate.cs
+++ b/OpenSim/Framework/Communications/Capabilities/LLSDTaskScriptUpdate.cs
@@ -25,7 +25,7 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications.Capabilities
{
@@ -35,16 +35,16 @@ namespace OpenSim.Framework.Communications.Capabilities
///
/// The item containing the script to update
///
- public LLUUID item_id;
+ public UUID item_id;
///
/// The task containing the script
///
- public LLUUID task_id;
+ public UUID task_id;
///
/// Signals whether the script is currently active
///
public int is_script_running;
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/CommunicationsManager.cs b/OpenSim/Framework/Communications/CommunicationsManager.cs
index 08dbc80..e6413e8 100644
--- a/OpenSim/Framework/Communications/CommunicationsManager.cs
+++ b/OpenSim/Framework/Communications/CommunicationsManager.cs
@@ -28,7 +28,7 @@
using System;
using System.Collections.Generic;
using System.Reflection;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
using OpenSim.Framework.Communications.Cache;
using OpenSim.Framework.Servers;
@@ -42,7 +42,7 @@ namespace OpenSim.Framework.Communications
{
private static readonly ILog m_log = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);
- protected Dictionary m_nameRequestCache = new Dictionary();
+ protected Dictionary m_nameRequestCache = new Dictionary();
public IUserService UserService
{
@@ -238,8 +238,8 @@ namespace OpenSim.Framework.Communications
///
///
///
- /// The UUID of the added user. Returns LLUUID.Zero if the add was unsuccessful
- public LLUUID AddUser(string firstName, string lastName, string password, uint regX, uint regY)
+ /// The UUID of the added user. Returns UUID.Zero if the add was unsuccessful
+ public UUID AddUser(string firstName, string lastName, string password, uint regX, uint regY)
{
string md5PasswdHash = Util.Md5Hash(Util.Md5Hash(password) + ":" + String.Empty);
@@ -247,7 +247,7 @@ namespace OpenSim.Framework.Communications
UserProfileData userProf = UserService.GetUserProfile(firstName, lastName);
if (userProf == null)
{
- return LLUUID.Zero;
+ return UUID.Zero;
}
else
{
@@ -265,7 +265,7 @@ namespace OpenSim.Framework.Communications
/// The agent that who's friends list is being added to
/// The agent that being added to the friends list of the friends list owner
/// A uint bit vector for set perms that the friend being added has; 0 = none, 1=This friend can see when they sign on, 2 = map, 4 edit objects
- public void AddNewUserFriend(LLUUID friendlistowner, LLUUID friend, uint perms)
+ public void AddNewUserFriend(UUID friendlistowner, UUID friend, uint perms)
{
m_userService.AddNewUserFriend(friendlistowner, friend, perms);
}
@@ -279,7 +279,7 @@ namespace OpenSim.Framework.Communications
///
///
///
- public void LogOffUser(LLUUID userid, LLUUID regionid, ulong regionhandle, float posx, float posy, float posz)
+ public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz)
{
m_userService.LogOffUser(userid, regionid, regionhandle, posx, posy, posz);
@@ -290,7 +290,7 @@ namespace OpenSim.Framework.Communications
///
/// The agent that who's friends list is being updated
/// The Ex-friend agent
- public void RemoveUserFriend(LLUUID friendlistowner, LLUUID friend)
+ public void RemoveUserFriend(UUID friendlistowner, UUID friend)
{
m_userService.RemoveUserFriend(friendlistowner, friend);
}
@@ -301,16 +301,16 @@ namespace OpenSim.Framework.Communications
/// The agent that who's friends list is being updated
/// The agent that is getting or loosing permissions
/// A uint bit vector for set perms that the friend being added has; 0 = none, 1=This friend can see when they sign on, 2 = map, 4 edit objects
- public void UpdateUserFriendPerms(LLUUID friendlistowner, LLUUID friend, uint perms)
+ public void UpdateUserFriendPerms(UUID friendlistowner, UUID friend, uint perms)
{
m_userService.UpdateUserFriendPerms(friendlistowner, friend, perms);
}
///
- /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for LLUUID friendslistowner
+ /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for UUID friendslistowner
///
/// The agent that we're retreiving the friends Data.
- public List GetUserFriendList(LLUUID friendlistowner)
+ public List GetUserFriendList(UUID friendlistowner)
{
return m_userService.GetUserFriendList(friendlistowner);
}
@@ -325,7 +325,7 @@ namespace OpenSim.Framework.Communications
return;
}
- public void HandleUUIDNameRequest(LLUUID uuid, IClientAPI remote_client)
+ public void HandleUUIDNameRequest(UUID uuid, IClientAPI remote_client)
{
if (uuid == m_userProfileCacheService.libraryRoot.Owner)
{
@@ -342,7 +342,7 @@ namespace OpenSim.Framework.Communications
}
}
- private string[] doUUIDNameRequest(LLUUID uuid)
+ private string[] doUUIDNameRequest(UUID uuid)
{
string[] returnstring = new string[0];
bool doLookup = false;
@@ -366,7 +366,7 @@ namespace OpenSim.Framework.Communications
if (profileData != null)
{
returnstring = new string[2];
- // LLUUID profileId = profileData.ID;
+ // UUID profileId = profileData.ID;
returnstring[0] = profileData.FirstName;
returnstring[1] = profileData.SurName;
lock (m_nameRequestCache)
@@ -380,13 +380,13 @@ namespace OpenSim.Framework.Communications
}
- public bool UUIDNameCachedTest(LLUUID uuid)
+ public bool UUIDNameCachedTest(UUID uuid)
{
lock (m_nameRequestCache)
return m_nameRequestCache.ContainsKey(uuid);
}
- public string UUIDNameRequestString(LLUUID uuid)
+ public string UUIDNameRequestString(UUID uuid)
{
string[] names = doUUIDNameRequest(uuid);
if (names.Length == 2)
@@ -400,7 +400,7 @@ namespace OpenSim.Framework.Communications
return "(hippos)";
}
- public List GenerateAgentPickerRequestResponse(LLUUID queryID, string query)
+ public List GenerateAgentPickerRequestResponse(UUID queryID, string query)
{
List pickerlist = m_userService.GenerateAgentPickerRequestResponse(queryID, query);
return pickerlist;
diff --git a/OpenSim/Framework/Communications/IAvatarService.cs b/OpenSim/Framework/Communications/IAvatarService.cs
index 6c033e1..25b26dd 100644
--- a/OpenSim/Framework/Communications/IAvatarService.cs
+++ b/OpenSim/Framework/Communications/IAvatarService.cs
@@ -28,16 +28,16 @@
using System;
using System.Collections.Generic;
using System.Text;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications
{
public interface IAvatarService
{
/// Get's the User Appearance
- AvatarAppearance GetUserAppearance(LLUUID user);
+ AvatarAppearance GetUserAppearance(UUID user);
- void UpdateUserAppearance(LLUUID user, AvatarAppearance appearance);
+ void UpdateUserAppearance(UUID user, AvatarAppearance appearance);
}
}
diff --git a/OpenSim/Framework/Communications/IGridServices.cs b/OpenSim/Framework/Communications/IGridServices.cs
index fcc0db5..6c5d2e2 100644
--- a/OpenSim/Framework/Communications/IGridServices.cs
+++ b/OpenSim/Framework/Communications/IGridServices.cs
@@ -26,7 +26,7 @@
*/
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications
{
@@ -53,7 +53,7 @@ namespace OpenSim.Framework.Communications
List RequestNeighbours(uint x, uint y);
RegionInfo RequestNeighbourInfo(ulong regionHandle);
- RegionInfo RequestNeighbourInfo(LLUUID regionID);
+ RegionInfo RequestNeighbourInfo(UUID regionID);
RegionInfo RequestClosestRegion(string regionName);
Dictionary GetGridSettings();
List RequestNeighbourMapBlocks(int minX, int minY, int maxX, int maxY);
diff --git a/OpenSim/Framework/Communications/IInterRegionCommunications.cs b/OpenSim/Framework/Communications/IInterRegionCommunications.cs
index 57fb82d..3dd5561 100644
--- a/OpenSim/Framework/Communications/IInterRegionCommunications.cs
+++ b/OpenSim/Framework/Communications/IInterRegionCommunications.cs
@@ -25,7 +25,7 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications
{
@@ -35,16 +35,16 @@ namespace OpenSim.Framework.Communications
bool CheckRegion(string address, uint port);
bool InformRegionOfChildAgent(ulong regionHandle, AgentCircuitData agentData);
- bool InformRegionOfPrimCrossing(ulong regionHandle, LLUUID primID, string objData, int XMLMethod);
+ bool InformRegionOfPrimCrossing(ulong regionHandle, UUID primID, string objData, int XMLMethod);
bool RegionUp(SerializableRegionInfo region, ulong regionhandle);
bool ChildAgentUpdate(ulong regionHandle, ChildAgentDataUpdate cAgentData);
- bool ExpectAvatarCrossing(ulong regionHandle, LLUUID agentID, LLVector3 position, bool isFlying);
- bool ExpectPrimCrossing(ulong regionHandle, LLUUID primID, LLVector3 position, bool isFlying);
+ bool ExpectAvatarCrossing(ulong regionHandle, UUID agentID, Vector3 position, bool isFlying);
+ bool ExpectPrimCrossing(ulong regionHandle, UUID primID, Vector3 position, bool isFlying);
- bool AcknowledgeAgentCrossed(ulong regionHandle, LLUUID agentId);
- bool AcknowledgePrimCrossed(ulong regionHandle, LLUUID primID);
+ bool AcknowledgeAgentCrossed(ulong regionHandle, UUID agentId);
+ bool AcknowledgePrimCrossed(ulong regionHandle, UUID primID);
- bool TellRegionToCloseChildConnection(ulong regionHandle, LLUUID agentID);
+ bool TellRegionToCloseChildConnection(ulong regionHandle, UUID agentID);
}
}
diff --git a/OpenSim/Framework/Communications/IInterServiceInventoryServices.cs b/OpenSim/Framework/Communications/IInterServiceInventoryServices.cs
index a1f4c2e..5900f4e 100644
--- a/OpenSim/Framework/Communications/IInterServiceInventoryServices.cs
+++ b/OpenSim/Framework/Communications/IInterServiceInventoryServices.cs
@@ -26,7 +26,7 @@
*/
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications
{
@@ -40,7 +40,7 @@ namespace OpenSim.Framework.Communications
///
///
/// true if the inventory was successfully created, false otherwise
- bool CreateNewUserInventory(LLUUID user);
+ bool CreateNewUserInventory(UUID user);
///
/// Returns a list of all the folders in a given user's inventory.
@@ -48,6 +48,6 @@ namespace OpenSim.Framework.Communications
///
/// A flat list of the user's inventory folder tree,
/// null if there is no inventory for this user
- List GetInventorySkeleton(LLUUID userId);
+ List GetInventorySkeleton(UUID userId);
}
}
diff --git a/OpenSim/Framework/Communications/IInventoryServices.cs b/OpenSim/Framework/Communications/IInventoryServices.cs
index b00b1bf..aead3be 100644
--- a/OpenSim/Framework/Communications/IInventoryServices.cs
+++ b/OpenSim/Framework/Communications/IInventoryServices.cs
@@ -26,7 +26,7 @@
*/
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
using OpenSim.Framework.Communications.Cache;
namespace OpenSim.Framework.Communications
@@ -53,7 +53,7 @@ namespace OpenSim.Framework.Communications
///
///
///
- void RequestInventoryForUser(LLUUID userID, InventoryReceiptCallback callback);
+ void RequestInventoryForUser(UUID userID, InventoryReceiptCallback callback);
///
/// Add a new folder to the user's inventory
@@ -109,13 +109,13 @@ namespace OpenSim.Framework.Communications
///
///
///
- bool HasInventoryForUser(LLUUID userID);
+ bool HasInventoryForUser(UUID userID);
///
/// Retrieve the root inventory folder for the given user.
///
///
/// null if no root folder was found
- InventoryFolderBase RequestRootFolder(LLUUID userID);
+ InventoryFolderBase RequestRootFolder(UUID userID);
}
}
diff --git a/OpenSim/Framework/Communications/ISecureInventoryService.cs b/OpenSim/Framework/Communications/ISecureInventoryService.cs
index bd962d1..6d4ce46 100644
--- a/OpenSim/Framework/Communications/ISecureInventoryService.cs
+++ b/OpenSim/Framework/Communications/ISecureInventoryService.cs
@@ -26,7 +26,7 @@
*/
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
using OpenSim.Framework.Communications.Cache;
namespace OpenSim.Framework.Communications
@@ -47,69 +47,69 @@ namespace OpenSim.Framework.Communications
///
///
///
- void RequestInventoryForUser(LLUUID userID, LLUUID session_id, InventoryReceiptCallback callback);
+ void RequestInventoryForUser(UUID userID, UUID session_id, InventoryReceiptCallback callback);
///
/// Add a new folder to the user's inventory
///
///
/// true if the folder was successfully added
- bool AddFolder(InventoryFolderBase folder, LLUUID session_id);
+ bool AddFolder(InventoryFolderBase folder, UUID session_id);
///
/// Update a folder in the user's inventory
///
///
/// true if the folder was successfully updated
- bool UpdateFolder(InventoryFolderBase folder, LLUUID session_id);
+ bool UpdateFolder(InventoryFolderBase folder, UUID session_id);
///
/// Move an inventory folder to a new location
///
/// A folder containing the details of the new location
/// true if the folder was successfully moved
- bool MoveFolder(InventoryFolderBase folder, LLUUID session_id);
+ bool MoveFolder(InventoryFolderBase folder, UUID session_id);
///
/// Purge an inventory folder of all its items and subfolders.
///
///
/// true if the folder was successfully purged
- bool PurgeFolder(InventoryFolderBase folder, LLUUID session_id);
+ bool PurgeFolder(InventoryFolderBase folder, UUID session_id);
///
/// Add a new item to the user's inventory
///
///
/// true if the item was successfully added
- bool AddItem(InventoryItemBase item, LLUUID session_id);
+ bool AddItem(InventoryItemBase item, UUID session_id);
///
/// Update an item in the user's inventory
///
///
/// true if the item was successfully updated
- bool UpdateItem(InventoryItemBase item, LLUUID session_id);
+ bool UpdateItem(InventoryItemBase item, UUID session_id);
///
/// Delete an item from the user's inventory
///
///
/// true if the item was successfully deleted
- bool DeleteItem(InventoryItemBase item, LLUUID session_id);
+ bool DeleteItem(InventoryItemBase item, UUID session_id);
///
/// Does the given user have an inventory structure?
///
///
///
- bool HasInventoryForUser(LLUUID userID);
+ bool HasInventoryForUser(UUID userID);
///
/// Retrieve the root inventory folder for the given user.
///
///
/// null if no root folder was found
- InventoryFolderBase RequestRootFolder(LLUUID userID);
+ InventoryFolderBase RequestRootFolder(UUID userID);
}
}
diff --git a/OpenSim/Framework/Communications/IUserService.cs b/OpenSim/Framework/Communications/IUserService.cs
index c1ae0e2..07ea437 100644
--- a/OpenSim/Framework/Communications/IUserService.cs
+++ b/OpenSim/Framework/Communications/IUserService.cs
@@ -26,7 +26,7 @@
*/
using System.Collections.Generic;
-using libsecondlife;
+using OpenMetaverse;
namespace OpenSim.Framework.Communications
{
@@ -47,22 +47,22 @@ namespace OpenSim.Framework.Communications
///
/// The target UUID
/// A user profile. Returns null if no user profile is found.
- UserProfileData GetUserProfile(LLUUID userId);
+ UserProfileData GetUserProfile(UUID userId);
- UserAgentData GetAgentByUUID(LLUUID userId);
+ UserAgentData GetAgentByUUID(UUID userId);
- void ClearUserAgent(LLUUID avatarID);
- List GenerateAgentPickerRequestResponse(LLUUID QueryID, string Query);
+ void ClearUserAgent(UUID avatarID);
+ List GenerateAgentPickerRequestResponse(UUID QueryID, string Query);
UserProfileData SetupMasterUser(string firstName, string lastName);
UserProfileData SetupMasterUser(string firstName, string lastName, string password);
- UserProfileData SetupMasterUser(LLUUID userId);
+ UserProfileData SetupMasterUser(UUID userId);
///
///
///
///
- LLUUID AddUserProfile(string firstName, string lastName, string pass, uint regX, uint regY);
+ UUID AddUserProfile(string firstName, string lastName, string pass, uint regX, uint regY);
///
/// Update the user's profile.
@@ -78,14 +78,14 @@ namespace OpenSim.Framework.Communications
/// The agent that who's friends list is being added to
/// The agent that being added to the friends list of the friends list owner
/// A uint bit vector for set perms that the friend being added has; 0 = none, 1=This friend can see when they sign on, 2 = map, 4 edit objects
- void AddNewUserFriend(LLUUID friendlistowner, LLUUID friend, uint perms);
+ void AddNewUserFriend(UUID friendlistowner, UUID friend, uint perms);
///
/// Delete friend on friendlistowner's friendlist.
///
/// The agent that who's friends list is being updated
/// The Ex-friend agent
- void RemoveUserFriend(LLUUID friendlistowner, LLUUID friend);
+ void RemoveUserFriend(UUID friendlistowner, UUID friend);
///
/// Update permissions for friend on friendlistowner's friendlist.
@@ -93,7 +93,7 @@ namespace OpenSim.Framework.Communications
/// The agent that who's friends list is being updated
/// The agent that is getting or loosing permissions
/// A uint bit vector for set perms that the friend being added has; 0 = none, 1=This friend can see when they sign on, 2 = map, 4 edit objects
- void UpdateUserFriendPerms(LLUUID friendlistowner, LLUUID friend, uint perms);
+ void UpdateUserFriendPerms(UUID friendlistowner, UUID friend, uint perms);
///
/// Updates a user profile
@@ -110,31 +110,31 @@ namespace OpenSim.Framework.Communications
/// final position x
/// final position y
/// final position z
- void LogOffUser(LLUUID userid, LLUUID regionid, ulong regionhandle, float posx, float posy, float posz);
+ void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz);
///
- /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for LLUUID friendslistowner
+ /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for UUID friendslistowner
///
/// The agent that we're retreiving the friends Data.
- List GetUserFriendList(LLUUID friendlistowner);
+ List GetUserFriendList(UUID friendlistowner);
///
/// Updates the current region the User is in
///
/// User Region the Avatar is IN
/// User Region the Avatar is IN
- void UpdateUserCurrentRegion(LLUUID avatarid, LLUUID regionuuid, ulong regionhandle);
+ void UpdateUserCurrentRegion(UUID avatarid, UUID regionuuid, ulong regionhandle);
///
/// Get's the User Appearance
- // AvatarAppearance GetUserAppearance(LLUUID user);
+ // AvatarAppearance GetUserAppearance(UUID user);
- // void UpdateUserAppearance(LLUUID user, AvatarAppearance appearance);
+ // void UpdateUserAppearance(UUID user, AvatarAppearance appearance);
- // void AddAttachment(LLUUID user, LLUUID attach);
+ // void AddAttachment(UUID user, UUID attach);
- // void RemoveAttachment(LLUUID user, LLUUID attach);
+ // void RemoveAttachment(UUID user, UUID attach);
- // List GetAttachments(LLUUID user);
+ // List GetAttachments(UUID user);
}
-}
\ No newline at end of file
+}
diff --git a/OpenSim/Framework/Communications/InventoryServiceBase.cs b/OpenSim/Framework/Communications/InventoryServiceBase.cs
index c76c078..3239268 100644
--- a/OpenSim/Framework/Communications/InventoryServiceBase.cs
+++ b/OpenSim/Framework/Communications/InventoryServiceBase.cs
@@ -30,7 +30,7 @@ using System.Collections.Generic;
using System.Reflection;
using System.Threading;
-using libsecondlife;
+using OpenMetaverse;
using log4net;
namespace OpenSim.Framework.Communications
@@ -57,7 +57,7 @@ namespace OpenSim.Framework.Communications
new PluginLoader (new InventoryDataInitialiser (connect));
// loader will try to load all providers (MySQL, MSSQL, etc)
- // unless it is constrainted to the correct "Provider" entry in the addin.xml
+ // unless it is constrainted to the correct "Provider" entry in the addin.Xml
loader.Add ("/OpenSim/InventoryData", new PluginProviderFilter (provider));
loader.Load();
@@ -74,7 +74,7 @@ namespace OpenSim.Framework.Communications
}
// See IInventoryServices
- public List GetInventorySkeleton(LLUUID userId)
+ public List GetInventorySkeleton(UUID userId)
{
// m_log.DebugFormat("[AGENT INVENTORY]: Getting inventory skeleton for {0}", userId);
@@ -105,13 +105,13 @@ namespace OpenSim.Framework.Communications
}
// See IInventoryServices
- public virtual bool HasInventoryForUser(LLUUID userID)
+ public virtual bool HasInventoryForUser(UUID userID)
{
return false;
}
// See IInventoryServices
- public InventoryFolderBase RequestRootFolder(LLUUID userID)
+ public InventoryFolderBase RequestRootFolder(UUID userID)
{
// FIXME: Probably doesn't do what was originally intended - only ever queries the first plugin
foreach (IInventoryDataPlugin plugin in m_plugins)
@@ -122,7 +122,7 @@ namespace OpenSim.Framework.Communications
}
// See IInventoryServices
- public bool CreateNewUserInventory(LLUUID user)
+ public bool CreateNewUserInventory(UUID user)
{
InventoryFolderBase existingRootFolder = RequestRootFolder(user);
@@ -146,13 +146,13 @@ namespace OpenSim.Framework.Communications
}
// See IInventoryServices
- public abstract void RequestInventoryForUser(LLUUID userID, InventoryReceiptCallback callback);
+ public abstract void RequestInventoryForUser(UUID userID, InventoryReceiptCallback callback);
#endregion
#region Methods used by GridInventoryService
- public List RequestSubFolders(LLUUID parentFolderID)
+ public List RequestSubFolders(UUID parentFolderID)
{
List inventoryList = new List();
foreach (IInventoryDataPlugin plugin in m_plugins)
@@ -162,7 +162,7 @@ namespace OpenSim.Framework.Communications
return inventoryList;
}
- public List RequestFolderItems(LLUUID folderID)
+ public List RequestFolderItems(UUID folderID)
{
List itemsList = new List();
foreach (IInventoryDataPlugin plugin in m_plugins)
@@ -313,27 +313,27 @@ namespace OpenSim.Framework.Communications
///
private class UsersInventory
{
- public Dictionary Folders = new Dictionary();
- public Dictionary Items = new Dictionary();
+ public Dictionary Folders = new Dictionary();
+ public Dictionary Items = new Dictionary();
- public virtual void CreateNewInventorySet(LLUUID user)
+ public virtual void CreateNewInventorySet(UUID user)
{
InventoryFolderBase folder = new InventoryFolderBase();
- folder.ParentID = LLUUID.Zero;
+ folder.ParentID = UUID.Zero;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "My Inventory";
folder.Type = (short)AssetType.Folder;
folder.Version = 1;
Folders.Add(folder.ID, folder);
- LLUUID rootFolder = folder.ID;
+ UUID rootFolder = folder.ID;
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Animations";
folder.Type = (short)AssetType.Animation;
folder.Version = 1;
@@ -342,7 +342,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Body Parts";
folder.Type = (short)AssetType.Bodypart;
folder.Version = 1;
@@ -351,7 +351,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Calling Cards";
folder.Type = (short)AssetType.CallingCard;
folder.Version = 1;
@@ -360,7 +360,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Clothing";
folder.Type = (short)AssetType.Clothing;
folder.Version = 1;
@@ -369,7 +369,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Gestures";
folder.Type = (short)AssetType.Gesture;
folder.Version = 1;
@@ -378,7 +378,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Landmarks";
folder.Type = (short)AssetType.Landmark;
folder.Version = 1;
@@ -387,7 +387,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Lost And Found";
folder.Type = (short)AssetType.LostAndFoundFolder;
folder.Version = 1;
@@ -396,7 +396,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Notecards";
folder.Type = (short)AssetType.Notecard;
folder.Version = 1;
@@ -405,7 +405,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Objects";
folder.Type = (short)AssetType.Object;
folder.Version = 1;
@@ -414,7 +414,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Photo Album";
folder.Type = (short)AssetType.SnapshotFolder;
folder.Version = 1;
@@ -423,7 +423,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Scripts";
folder.Type = (short)AssetType.LSLText;
folder.Version = 1;
@@ -432,7 +432,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Sounds";
folder.Type = (short)AssetType.Sound;
folder.Version = 1;
@@ -441,7 +441,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Textures";
folder.Type = (short)AssetType.Texture;
folder.Version = 1;
@@ -450,7 +450,7 @@ namespace OpenSim.Framework.Communications
folder = new InventoryFolderBase();
folder.ParentID = rootFolder;
folder.Owner = user;
- folder.ID = LLUUID.Random();
+ folder.ID = UUID.Random();
folder.Name = "Trash";
folder.Type = (short)AssetType.TrashFolder;
folder.Version = 1;
diff --git a/OpenSim/Framework/Communications/LoginResponse.cs b/OpenSim/Framework/Communications/LoginResponse.cs
index 686d1bb..16be2b7 100644
--- a/OpenSim/Framework/Communications/LoginResponse.cs
+++ b/OpenSim/Framework/Communications/LoginResponse.cs
@@ -29,8 +29,8 @@ using System;
using System.Collections;
using System.Collections.Generic;
using System.Reflection;
-using libsecondlife;
-using libsecondlife.StructuredData;
+using OpenMetaverse;
+using OpenMetaverse.StructuredData;
using log4net;
using Nwc.XmlRpc;
@@ -63,9 +63,9 @@ namespace OpenSim.Framework.Communications
private UserInfo userProfile;
- private LLUUID agentID;
- private LLUUID sessionID;
- private LLUUID secureSessionID;
+ private UUID agentID;
+ private UUID sessionID;
+ private UUID secureSessionID;
// Login Flags
private string dst;
@@ -171,9 +171,9 @@ namespace OpenSim.Framework.Communications
AddClassifiedCategory((Int32) 8, "Service");
AddClassifiedCategory((Int32) 9, "Personal");
- SessionID = LLUUID.Random();
- SecureSessionID = LLUUID.Random();
- AgentID = LLUUID.Random();
+ SessionID = UUID.Random();
+ SecureSessionID = UUID.Random();
+ AgentID = UUID.Random();
Hashtable InitialOutfitHash = new Hashtable();
InitialOutfitHash["folder_name"] = "Nightclub Female";
@@ -567,19 +567,19 @@ namespace OpenSim.Framework.Communications
set { simAddress = value; }
}
- public LLUUID AgentID
+ public UUID AgentID
{
get { return agentID; }
set { agentID = value; }
}
- public LLUUID SessionID
+ public UUID SessionID
{
get { return sessionID; }
set { sessionID = value; }
}
- public LLUUID SecureSessionID
+ public UUID SecureSessionID
{
get { return secureSessionID; }
set { secureSessionID = value; }
@@ -724,8 +724,8 @@ namespace OpenSim.Framework.Communications
public string firstname;
public string lastname;
public ulong homeregionhandle;
- public LLVector3 homepos;
- public LLVector3 homelookat;
+ public Vector3 homepos;
+ public Vector3 homelookat;
}
public class BuddyList
@@ -754,14 +754,14 @@ namespace OpenSim.Framework.Communications
{
public int BuddyRightsHave = 1;
public int BuddyRightsGiven = 1;
- public LLUUID BuddyID;
+ public UUID BuddyID;
public BuddyInfo(string buddyID)
{
- BuddyID = new LLUUID(buddyID);
+ BuddyID = new UUID(buddyID);
}
- public BuddyInfo(LLUUID buddyID)
+ public BuddyInfo(UUID buddyID)
{
BuddyID = buddyID;
}
diff --git a/OpenSim/Framework/Communications/UserManagerBase.cs b/OpenSim/Framework/Communications/UserManagerBase.cs
index a35ed72..5a63e70 100644
--- a/OpenSim/Framework/Communications/UserManagerBase.cs
+++ b/OpenSim/Framework/Communications/UserManagerBase.cs
@@ -31,8 +31,8 @@ using System.Collections.Generic;
using System.Net;
using System.Reflection;
using System.Security.Cryptography;
-using libsecondlife;
-using libsecondlife.StructuredData;
+using OpenMetaverse;
+using OpenMetaverse.StructuredData;
using log4net;
using Nwc.XmlRpc;
using OpenSim.Framework.Statistics;
@@ -59,7 +59,7 @@ namespace OpenSim.Framework.Communications
new PluginLoader (new UserDataInitialiser (connect));
// loader will try to load all providers (MySQL, MSSQL, etc)
- // unless it is constrainted to the correct "Provider" entry in the addin.xml
+ // unless it is constrainted to the correct "Provider" entry in the addin.Xml
loader.Add ("/OpenSim/UserData", new PluginProviderFilter (provider));
loader.Load();
@@ -84,14 +84,14 @@ namespace OpenSim.Framework.Communications
return null;
}
- public void ResetAttachments(LLUUID userID)
+ public void ResetAttachments(UUID userID)
{
foreach (IUserDataPlugin plugin in _plugins)
{
plugin.ResetAttachments(userID);
}
}
- public UserAgentData GetAgentByUUID(LLUUID userId)
+ public UserAgentData GetAgentByUUID(UUID userId)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -106,7 +106,7 @@ namespace OpenSim.Framework.Communications
return null;
}
// see IUserService
- public UserProfileData GetUserProfile(LLUUID uuid)
+ public UserProfileData GetUserProfile(UUID uuid)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -122,7 +122,7 @@ namespace OpenSim.Framework.Communications
return null;
}
- public List GenerateAgentPickerRequestResponse(LLUUID queryID, string query)
+ public List GenerateAgentPickerRequestResponse(UUID queryID, string query)
{
List pickerlist = new List();
foreach (IUserDataPlugin plugin in _plugins)
@@ -172,7 +172,7 @@ namespace OpenSim.Framework.Communications
///
/// The agent's UUID
/// Agent profiles
- public UserAgentData GetUserAgent(LLUUID uuid)
+ public UserAgentData GetUserAgent(UUID uuid)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -234,7 +234,7 @@ namespace OpenSim.Framework.Communications
return null;
}
- public void UpdateUserCurrentRegion(LLUUID avatarid, LLUUID regionuuid, ulong regionhandle)
+ public void UpdateUserCurrentRegion(UUID avatarid, UUID regionuuid, ulong regionhandle)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -254,7 +254,7 @@ namespace OpenSim.Framework.Communications
///
/// the UUID of the friend list owner
/// A List of FriendListItems that contains info about the user's friends
- public List GetUserFriendList(LLUUID ownerID)
+ public List GetUserFriendList(UUID ownerID)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -271,7 +271,7 @@ namespace OpenSim.Framework.Communications
return null;
}
- public void StoreWebLoginKey(LLUUID agentID, LLUUID webLoginKey)
+ public void StoreWebLoginKey(UUID agentID, UUID webLoginKey)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -286,7 +286,7 @@ namespace OpenSim.Framework.Communications
}
}
- public void AddNewUserFriend(LLUUID friendlistowner, LLUUID friend, uint perms)
+ public void AddNewUserFriend(UUID friendlistowner, UUID friend, uint perms)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -301,7 +301,7 @@ namespace OpenSim.Framework.Communications
}
}
- public void RemoveUserFriend(LLUUID friendlistowner, LLUUID friend)
+ public void RemoveUserFriend(UUID friendlistowner, UUID friend)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -316,7 +316,7 @@ namespace OpenSim.Framework.Communications
}
}
- public void UpdateUserFriendPerms(LLUUID friendlistowner, LLUUID friend, uint perms)
+ public void UpdateUserFriendPerms(UUID friendlistowner, UUID friend, uint perms)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -336,7 +336,7 @@ namespace OpenSim.Framework.Communications
/// Resets the currentAgent in the user profile
///
/// The agent's ID
- public void ClearUserAgent(LLUUID agentID)
+ public void ClearUserAgent(UUID agentID)
{
UserProfileData profile = GetUserProfile(agentID);
@@ -382,8 +382,8 @@ namespace OpenSim.Framework.Communications
rand.GetBytes(randDataS);
rand.GetBytes(randDataSS);
- agent.SecureSessionID = new LLUUID(randDataSS, 0);
- agent.SessionID = new LLUUID(randDataS, 0);
+ agent.SecureSessionID = new UUID(randDataSS, 0);
+ agent.SessionID = new UUID(randDataS, 0);
// Profile UUID
agent.ProfileID = profile.ID;
@@ -434,8 +434,8 @@ namespace OpenSim.Framework.Communications
agent.LogoutTime = 0;
// Current location
- agent.InitialRegion = LLUUID.Zero; // Fill in later
- agent.Region = LLUUID.Zero; // Fill in later
+ agent.InitialRegion = UUID.Zero; // Fill in later
+ agent.Region = UUID.Zero; // Fill in later
profile.CurrentAgent = agent;
}
@@ -449,14 +449,14 @@ namespace OpenSim.Framework.Communications
///
///
///
- public void LogOffUser(LLUUID userid, LLUUID regionid, ulong regionhandle, float posx, float posy, float posz)
+ public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz)
{
if (StatsManager.UserStats != null)
StatsManager.UserStats.AddLogout();
UserProfileData userProfile;
UserAgentData userAgent;
- LLVector3 currentPos = new LLVector3(posx, posy, posz);
+ Vector3 currentPos = new Vector3(posx, posy, posz);
userProfile = GetUserProfile(userid);
@@ -470,8 +470,8 @@ namespace OpenSim.Framework.Communications
{
userAgent.AgentOnline = false;
userAgent.LogoutTime = Util.UnixTimeSinceEpoch();
- //userAgent.sessionID = LLUUID.Zero;
- if (regionid != LLUUID.Zero)
+ //userAgent.sessionID = UUID.Zero;
+ if (regionid != UUID.Zero)
{
userAgent.Region = regionid;
}
@@ -508,8 +508,8 @@ namespace OpenSim.Framework.Communications
rand.GetBytes(randDataS);
rand.GetBytes(randDataSS);
- agent.SecureSessionID = new LLUUID(randDataSS, 0);
- agent.SessionID = new LLUUID(randDataS, 0);
+ agent.SecureSessionID = new UUID(randDataSS, 0);
+ agent.SessionID = new UUID(randDataS, 0);
// Profile UUID
agent.ProfileID = profile.ID;
@@ -523,8 +523,8 @@ namespace OpenSim.Framework.Communications
agent.LogoutTime = 0;
// Current location
- agent.InitialRegion = LLUUID.Zero; // Fill in later
- agent.Region = LLUUID.Zero; // Fill in later
+ agent.InitialRegion = UUID.Zero; // Fill in later
+ agent.Region = UUID.Zero; // Fill in later
profile.CurrentAgent = agent;
}
@@ -550,17 +550,17 @@ namespace OpenSim.Framework.Communications
///
///
///
- public LLUUID AddUserProfile(string firstName, string lastName, string pass, uint regX, uint regY)
+ public UUID AddUserProfile(string firstName, string lastName, string pass, uint regX, uint regY)
{
UserProfileData user = new UserProfileData();
- user.HomeLocation = new LLVector3(128, 128, 100);
- user.ID = LLUUID.Random();
+ user.HomeLocation = new Vector3(128, 128, 100);
+ user.ID = UUID.Random();
user.FirstName = firstName;
user.SurName = lastName;
user.PasswordHash = pass;
user.PasswordSalt = String.Empty;
user.Created = Util.UnixTimeSinceEpoch();
- user.HomeLookAt = new LLVector3(100, 100, 100);
+ user.HomeLookAt = new Vector3(100, 100, 100);
user.HomeRegionX = regX;
user.HomeRegionY = regY;
@@ -604,7 +604,7 @@ namespace OpenSim.Framework.Communications
public abstract UserProfileData SetupMasterUser(string firstName, string lastName);
public abstract UserProfileData SetupMasterUser(string firstName, string lastName, string password);
- public abstract UserProfileData SetupMasterUser(LLUUID uuid);
+ public abstract UserProfileData SetupMasterUser(UUID uuid);
///
/// Add agent to DB
@@ -629,7 +629,7 @@ namespace OpenSim.Framework.Communications
/// Appearance
/// TODO: stubs for now to get us to a compiling state gently
- public AvatarAppearance GetUserAppearance(LLUUID user)
+ public AvatarAppearance GetUserAppearance(UUID user)
{
foreach (IUserDataPlugin plugin in _plugins)
{
@@ -645,7 +645,7 @@ namespace OpenSim.Framework.Communications
return null;
}
- public void UpdateUserAppearance(LLUUID user, AvatarAppearance appearance)
+ public void UpdateUserAppearance(UUID user, AvatarAppearance appearance)
{
foreach (IUserDataPlugin plugin in _plugins)
{
diff --git a/OpenSim/Framework/Communications/LoginService.cs b/OpenSim/Framework/Communications/LoginService.cs
index 73fba1e..d8d0fa2 100644
--- a/OpenSim/Framework/Communications/LoginService.cs
+++ b/OpenSim/Framework/Communications/LoginService.cs
@@ -33,8 +33,8 @@ using System.Reflection;
using System.Text.RegularExpressions;
using System.Threading;
using System.Web;
-using libsecondlife;
-using libsecondlife.StructuredData;
+using OpenMetaverse;
+using OpenMetaverse.StructuredData;
using log4net;
using Nwc.XmlRpc;
using OpenSim.Framework.Communications.Cache;
@@ -94,7 +94,7 @@ namespace OpenSim.Framework.Communications
///
///
/// This will be thrown if there is a problem with the inventory service
- protected abstract InventoryData GetInventorySkeleton(LLUUID userID);
+ protected abstract InventoryData GetInventorySkeleton(UUID userID);
///
/// Called when we receive the client's initial XMLRPC login_to_simulator request message
@@ -163,10 +163,10 @@ namespace OpenSim.Framework.Communications
}
else if (requestData.Contains("web_login_key"))
{
- LLUUID webloginkey = null;
+ UUID webloginkey = null;
try
{
- webloginkey = new LLUUID((string)requestData["web_login_key"]);
+ webloginkey = new UUID((string)requestData["web_login_key"]);
}
catch (Exception e)
{
@@ -227,7 +227,7 @@ namespace OpenSim.Framework.Communications
try
{
- LLUUID agentID = userProfile.ID;
+ UUID agentID = userProfile.ID;
InventoryData inventData = null;
try
@@ -400,7 +400,7 @@ namespace OpenSim.Framework.Communications
try
{
- LLUUID agentID = userProfile.ID;
+ UUID agentID = userProfile.ID;
//InventoryData inventData = GetInventorySkeleton(agentID);
InventoryData inventData = null;
@@ -566,7 +566,7 @@ namespace OpenSim.Framework.Communications
if (goodweblogin)
{
- LLUUID webloginkey = LLUUID.Random();
+ UUID webloginkey = UUID.Random();
m_userManager.StoreWebLoginKey(user.ID, webloginkey);
statuscode = 301;
@@ -737,13 +737,13 @@ namespace OpenSim.Framework.Communications
return passwordSuccess;
}
- public virtual bool AuthenticateUser(UserProfileData profile, LLUUID webloginkey)
+ public virtual bool AuthenticateUser(UserProfileData profile, UUID webloginkey)
{
bool passwordSuccess = false;
m_log.InfoFormat("[LOGIN]: Authenticating {0} {1} ({2})", profile.FirstName, profile.SurName, profile.ID);
- // Match web login key unless it's the default weblogin key LLUUID.Zero
- passwordSuccess = ((profile.WebLoginKey==webloginkey) && profile.WebLoginKey != LLUUID.Zero);
+ // Match web login key unless it's the default weblogin key UUID.Zero
+ passwordSuccess = ((profile.WebLoginKey==webloginkey) && profile.WebLoginKey != UUID.Zero);
return passwordSuccess;
}
@@ -803,7 +803,7 @@ namespace OpenSim.Framework.Communications
///
protected virtual ArrayList GetInventoryLibrary()
{
- Dictionary rootFolders
+ Dictionary rootFolders
= m_libraryRootFolder.RequestSelfAndDescendentFolders();
ArrayList folderHashes = new ArrayList();
@@ -838,9 +838,9 @@ namespace OpenSim.Framework.Communications
public class InventoryData
{
public ArrayList InventoryArray = null;
- public LLUUID RootFolderID = LLUUID.Zero;
+ public UUID RootFolderID = UUID.Zero;
- public InventoryData(ArrayList invList, LLUUID rootID)
+ public InventoryData(ArrayList invList, UUID rootID)
{
InventoryArray = invList;
RootFolderID = rootID;
--
cgit v1.1